@@ -17,10 +17,13 @@
 
 from __future__ import absolute_import
 
+from typing import Union
+
 import logging
 from datetime import datetime
 
 from .util import fresh_operation
+from .models import Error, Event, EventResult
 
 
 class Events:
@@ -31,7 +34,7 @@ class Events:
 
     def list_events(
         self, since=None, to=None, stream_position=None, max_count=None, numeric_dates=None # pylint: disable=invalid-name
-    ):
+    ) -> Union[EventResult[Event], Error]:
         """Get the list of all Events.
 
         Args:
@@ -53,7 +56,7 @@ class Events:
                 Default is false, which means ISO-8601 format
 
         Returns:
-            EventResult containing Event array as data[]
+            Union[EventResult[Event], Error]: The result of the operation, or an Error object if the request fails.
         """
         _op = fresh_operation("list_events")
         _op["method"] = "GET"
